@@ -8,10 +8,9 @@
 
 import warnings
 from math import floor, log10
-from typing import TYPE_CHECKING, Union
+from typing import Union
 
 import geopandas as gpd
-
 import numpy as np
 import pandas as pd
 import pygmt
